@@ -57,9 +57,9 @@ def run_pipeline(config, start_module_name):
         inDir=config.inDir,
         outDir=config.outDir,
         randomSampleSize=config.randomSampleSize,
-        maskObject=config.maskObject,
+        sampleNames=config.sampleNames,
         sampleConditions=config.sampleConditions,
-        sampleAbbreviations=config.sampleAbbreviations,
+        sampleConditionAbbrs=config.sampleConditionAbbrs,
         sampleStatuses=config.sampleStatuses,
         sampleReplicates=config.sampleReplicates,
         samplesToExclude=config.samplesToExclude,
@@ -82,10 +82,9 @@ def run_pipeline(config, start_module_name):
         samplesToRemovePCA=config.samplesToRemovePCA,
         dimensionPCA=config.dimensionPCA,
         pointSize=config.pointSize,
-        normalize=config.normalize,
         labelPoints=config.labelPoints,
         distanceCutoff=config.distanceCutoff,
-        samplesToSilhouette=config.samplesToSilhouette,
+        conditionsToSilhouette=config.conditionsToSilhouette,
 
         embeddingAlgorithmQC=config.embeddingAlgorithmQC,
         embeddingAlgorithm=config.embeddingAlgorithm,
